/*
 * Copyright (c) 2006-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: MyLeadAgentStubTestCase.java,v 1.8 2007/03/08 02:55:58 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.test;

import java.util.ArrayList;
import java.util.List;

import org.xmlpull.infoset.XmlElement;

import xsul5.MLogger;
import edu.indiana.dde.mylead.common.MyLeadBasicContentFilter;
import edu.indiana.dde.mylead.common.MyLeadProject;
import edu.indiana.extreme.lead.metadata.LEADresourceDocument;
import edu.indiana.extreme.lead.metadata.util.MinimalLEADMetadata;
import edu.indiana.extreme.xbaya.mylead.MyLead;
import edu.indiana.extreme.xbaya.mylead.MyLeadAgentStub;
import edu.indiana.extreme.xbaya.mylead.MyLeadException;
import edu.indiana.extreme.xbaya.mylead.MyLeadQueryResultItem;
import edu.indiana.extreme.xbaya.myproxy.MyProxyClient;
import edu.indiana.extreme.xbaya.util.XMLUtil;

/**
 * @author Satoshi Shirasuna
 */
public class MyLeadAgentStubTestCase extends XBayaTestCase {

    private static final MLogger logger = MLogger.getLogger();

    private static final String FAKE_USER_ID = "/C=US/O=National Center for Supercomputing Applications/CN=Fake User";

    private MyProxyClient myProxyClient;

    /**
     * @see edu.indiana.extreme.xbaya.test.XBayaTestCase#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();

        this.myProxyClient = new MyProxyClient(this.configuration
                .getMyProxyServer(), this.configuration.getMyProxyPort(),
                this.configuration.getMyProxyUsername(), this.configuration
                        .getMyProxyPassphrase(), this.configuration
                        .getMyProxyLifetime());
        this.myProxyClient.load();
    }

    /**
     * @throws MyLeadException
     */
    public void testDoesUserHaveMyLeadAccount() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());
        boolean result = stub.doesUserHaveMyLeadAccount(this.configuration
                .getMyLeadUser());
        assertEquals(true, result);

        boolean result2 = stub.doesUserHaveMyLeadAccount(FAKE_USER_ID);
        assertEquals(false, result2);
    }

    /**
     * @throws MyLeadException
     */
    public void estAddNewUser() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());
        String result = stub.addNewUser(FAKE_USER_ID, FAKE_USER_ID);
        logger.info("result: " + result);
    }

    /**
     * @throws MyLeadException
     */
    public void estCreateProject() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());

        MinimalLEADMetadata projectMetadata = new MinimalLEADMetadata(
                FAKE_USER_ID, "Project1", "Project description");
        projectMetadata.setResourceId("Unknown"); // this is neccesary.
        projectMetadata.construct();
        String projectID = stub.createProject(FAKE_USER_ID, projectMetadata
                .toString(), true);

        MinimalLEADMetadata workflowTemplatesMetadata = new MinimalLEADMetadata(
                FAKE_USER_ID, MyLead.WORKFLOW_TEMPLATES_COLLECTION,
                "Workflow templates collection description");
        // This is neccesary.
        workflowTemplatesMetadata.setResourceId("Unknown");
        workflowTemplatesMetadata.construct();
        String workflowTemplatesCollectionID = stub.createCollection(
                FAKE_USER_ID, workflowTemplatesMetadata.toString(), projectID,
                true);
        logger.info("workflowTemplatesCollectionID: "
                + workflowTemplatesCollectionID);
    }

    /**
     * @throws MyLeadException
     * 
     */
    public void testListProjectsInFullFormat() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());
        String user = this.configuration.getMyLeadUser();

        int limit = 0;
        String hFilter = MyLeadAgentStub.HFILTER_TARGET;

        MyLeadBasicContentFilter cFilter = new MyLeadBasicContentFilter();
        cFilter.setFilter(MyLeadBasicContentFilter.FULL_SCHEMA_CONTENT_FILTER);

        MyLeadProject myLeadProject = new MyLeadProject();
        String target = myLeadProject.wrapParameters();
        XmlElement resultElement = stub.queryLead(user, limit, hFilter, cFilter
                .wrapFilter(), target);
        logger.finest("resultElement: "
                + XMLUtil.xmlElementToString(resultElement));
    }

    /**
     * @throws MyLeadException
     * 
     */
    public void testListProjects() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());

        ArrayList<MyLeadQueryResultItem> projects = stub
                .listProjects(this.configuration.getMyLeadUser());
        for (MyLeadQueryResultItem project : projects) {
            String projectID = project.getResouceID();
            logger.info("projectID: " + projectID);
            String title = project.getTitle();
            logger.info("title: " + title);
        }
    }

    /**
     * @throws MyLeadException
     */
    public void testProjectNameToID() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());

        String user = this.configuration.getMyLeadUser();
        String projectName = this.configuration.getMyLeadProject();
        String projectID = stub.projectNameToID(user, projectName);
        logger.info("projectID: " + projectID);
    }

    /**
     * @throws MyLeadException
     */
    public void testQueryById() throws MyLeadException {
        MyLeadAgentStub stub = new MyLeadAgentStub(this.configuration
                .getMyLeadAgentURL(), this.myProxyClient.getProxy());
        String user = this.configuration.getMyLeadUser();
        String projectName = this.configuration.getMyLeadProject();

        String projectID = stub.projectNameToID(user, projectName);
        logger.info("projectID: " + projectID);

        String templateCollectionID = stub.collectionNameToID(user, projectID,
                MyLead.WORKFLOW_TEMPLATES_COLLECTION);
        logger.info("templateCollectionID: " + templateCollectionID);

        List<MyLeadQueryResultItem> templates = stub.listCollections(user,
                templateCollectionID);
        for (MyLeadQueryResultItem template : templates) {
            String templateTitle = template.getTitle();
            logger.info("templateTitle: " + templateTitle);
            String templateResourceID = template.getResouceID();

            LEADresourceDocument leadMetadata = stub.getCollection(user,
                    templateResourceID);
            logger.info(leadMetadata.toString());
        }
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
